@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -344,10 +344,14 @@ class DirectUnpacker(threading.Thread):
     def have_next_volume(self):
         """Check if next volume of set is available, start
         from the end of the list where latest completed files are
-        Make sure that files are 100% written to disk by checking md5sum
+        Make sure that files are 100% written to disk by checking nzf.assembled
         """
         for nzf_search in reversed(self.nzo.finished_files):
-            if nzf_search.setname == self.cur_setname and nzf_search.vol == (self.cur_volume + 1) and nzf_search.md5sum:
+            if (
+                nzf_search.setname == self.cur_setname
+                and nzf_search.vol == (self.cur_volume + 1)
+                and nzf_search.assembled
+            ):
                 return nzf_search
         return False
 
@@ -414,7 +418,6 @@ class DirectUnpacker(threading.Thread):
                 "%s\\" % long_path(extraction_path),
             ]
         else:
-            # Don't use "-ai" (not needed for non-Windows)
             # The -scf forces the output to be UTF8
             command = [
                 sabnzbd.newsunpack.RAR_COMMAND,
@@ -423,6 +426,7 @@ class DirectUnpacker(threading.Thread):
                 "-idp",
                 "-scf",
                 "-o+",
+                "-ai",
                 password_command,
                 rarfile_path,
                 "%s/" % extraction_path,
@@ -435,7 +439,9 @@ class DirectUnpacker(threading.Thread):
         self.cur_volume = 1
 
         # Need to disable buffer to have direct feedback
-        self.active_instance = build_and_run_command(command, windows_unrar_command=True, bufsize=0)
+        self.active_instance = build_and_run_command(
+            command, windows_unrar_command=True, text_mode=False, stdin=subprocess.PIPE
+        )
 
         # Add to runners
         ACTIVE_UNPACKERS.append(self)
