@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -31,7 +31,7 @@ from threading import Thread
 
 import sabnzbd
 import sabnzbd.cfg
-from sabnzbd.encoding import platform_btou, utob
+from sabnzbd.encoding import utob
 from sabnzbd.filesystem import make_script_path
 from sabnzbd.misc import build_and_run_command
 from sabnzbd.newsunpack import create_env
@@ -350,11 +350,11 @@ def send_nscript(title, msg, gtype, force=False, test=None):
     """Run user's notification script"""
     if test:
         script = test.get("nscript_script")
-        nscript_parameters = test.get("nscript_parameters")
+        env_params = {"notification_parameters": test.get("nscript_parameters")}
     else:
         script = sabnzbd.cfg.nscript_script()
-        nscript_parameters = sabnzbd.cfg.nscript_parameters()
-    nscript_parameters = nscript_parameters.split()
+        env_params = {"notification_parameters": sabnzbd.cfg.nscript_parameters()}
+
     if not script:
         return T("Cannot send, missing required data")
     title = "SABnzbd: " + T(NOTIFICATION.get(gtype, "other"))
@@ -365,17 +365,18 @@ def send_nscript(title, msg, gtype, force=False, test=None):
             ret = -1
             output = None
             try:
-                p = build_and_run_command([script_path, gtype, title, msg] + nscript_parameters, env=create_env())
-                output = platform_btou(p.stdout.read())
+                p = build_and_run_command([script_path, gtype, title, msg], env=create_env(extra_env_fields=env_params))
+                output = p.stdout.read()
                 ret = p.wait()
             except:
-                logging.info("Failed script %s, Traceback: ", script, exc_info=True)
+                logging.info("Failed to run script %s", script, exc_info=True)
 
             if ret:
                 logging.error(T('Script returned exit code %s and output "%s"'), ret, output)
                 return T('Script returned exit code %s and output "%s"') % (ret, output)
             else:
                 logging.info("Successfully executed notification script %s", script_path)
+                logging.debug("Script output: %s", output)
         else:
             return T('Notification script "%s" does not exist') % script_path
     return ""
