@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -56,7 +56,7 @@ def clean_cache_dir(request):
 
 
 @pytest.fixture(scope="module")
-def run_sabnzbd(clean_cache_dir):
+def run_sabnzbd(clean_cache_dir, request):
     """Start SABnzbd (with translations). A number of key configuration parameters are defined
     in testhelper.py (SAB_* variables). Scope is set to 'module' to prevent configuration
     changes made during functional tests from causing failures in unrelated tests."""
@@ -67,12 +67,15 @@ def run_sabnzbd(clean_cache_dir):
             get_url_result("shutdown", SAB_HOST, SAB_PORT)
         except requests.ConnectionError:
             sabnzbd_process.kill()
-            sabnzbd_process.communicate(timeout=10)
+            sabnzbd_process.communicate(timeout=30)
         except Exception as err:
             warn("Failed to shutdown the sabnzbd process: %s" % err)
 
+    # Allow the test file to specify what ini to load; if none given, use the basic one by default
+    ini_file = getattr(request.module, "INI_FILE", "sabnzbd.basic.ini")
+
     # Copy basic config file with API key
-    shutil.copyfile(os.path.join(SAB_DATA_DIR, "sabnzbd.basic.ini"), os.path.join(SAB_CACHE_DIR, DEF_INI_FILE))
+    shutil.copyfile(os.path.join(SAB_DATA_DIR, ini_file), os.path.join(SAB_CACHE_DIR, DEF_INI_FILE))
 
     # Check if we have language files
     locale_dir = os.path.join(SAB_BASE_DIR, "..", "locale")
@@ -106,7 +109,7 @@ def run_sabnzbd(clean_cache_dir):
     )
 
     # Wait for SAB to respond
-    for _ in range(10):
+    for _ in range(30):
         try:
             get_url_result()
             # Woohoo, we're up!
