@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -89,6 +89,23 @@ class TestFileFolderNameSanitizer:
         assert filesystem.sanitize_filename("$mft") == "$mft"
         assert filesystem.sanitize_filename("a$mft") == "a$mft"
 
+    @set_platform("win32")
+    def test_file_illegal_chars_win32(self):
+        assert filesystem.sanitize_filename("test" + filesystem.CH_ILLEGAL_WIN + "aftertest") == (
+            "test" + filesystem.CH_LEGAL_WIN + "aftertest"
+        )
+        assert (
+            filesystem.sanitize_filename("test" + chr(0) + chr(1) + chr(15) + chr(31) + "aftertest")
+            == "test____aftertest"
+        )
+
+    @set_platform("win32")
+    def test_folder_illegal_chars_win32(self):
+        assert (
+            filesystem.sanitize_foldername("test" + chr(0) + chr(9) + chr(13) + chr(31) + "aftertest")
+            == "test____aftertest"
+        )
+
     @set_platform("linux")
     def test_file_illegal_chars_linux(self):
         assert filesystem.sanitize_filename("test/aftertest") == "test+aftertest"
@@ -193,7 +210,6 @@ class TestFileFolderNameSanitizer:
         assert filesystem.sanitize_foldername(" . .") == "unknown"
 
     def test_filename_too_long(self):
-
         # Note: some filesystem can handle up to 255 UTF chars (which is more than 255 bytes) in the filename,
         # but we stay on the safe side: max DEF_FILE_MAX bytes
 
@@ -599,6 +615,16 @@ class TestListdirFull(ffs.TestCase):
         assert filesystem.listdir_full("/some/.DS_Store/", recursive=False) == []
         assert filesystem.listdir_full("/some/.DS_Store/subdir", recursive=False) == []
 
+    def test_exception_resource_files(self):
+        for file in (
+            "/rsc/base_file",
+            "/rsc/._base_file",
+            "/rsc/not._base_file",
+        ):
+            self.fs.create_file(file)
+            assert os.path.exists(file) is True
+        assert filesystem.listdir_full("/rsc") == ["/rsc/base_file", "/rsc/not._base_file"]
+
     def test_invalid_file_argument(self):
         # This is obviously not intended use; the function expects a directory
         # as its argument, not a file. Test anyway.
@@ -676,6 +702,16 @@ class TestListdirFullWin(ffs.TestCase):
         assert filesystem.listdir_full(r"f:\some\.DS_Store", recursive=True) == []
         assert filesystem.listdir_full(r"f:\some\.DS_Store\subdir", recursive=True) == []
 
+    def test_exception_resource_files(self):
+        for file in (
+            r"f:\rsc\base_file",
+            r"f:\rsc\._base_file",
+            r"f:\rsc\not._base_file",
+        ):
+            self.fs.create_file(file)
+            assert os.path.exists(file) is True
+        assert filesystem.listdir_full(r"f:\rsc") == [r"f:\rsc\base_file", r"f:\rsc\not._base_file"]
+
     def test_invalid_file_argument(self):
         # This is obviously not intended use; the function expects a directory
         # as its argument, not a file. Test anyway.
@@ -705,6 +741,15 @@ class TestGetUniqueDirFilename(ffs.TestCase):
             os.chdir("/")
         assert filesystem.get_unique_dir("foo/bar", n=0, create_dir=False) == "foo/bar"
 
+    def test_nonexistent_dir_without_permission(self):
+        some_dir = "/foo/bar"
+        self.fs.create_dir(some_dir)
+
+        # Remove write permission from the directory.
+        os.chmod(some_dir, 0o500)
+
+        assert filesystem.get_unique_dir(os.path.join(some_dir, "nonexistent"), create_dir=True) is False
+
     def test_creating_dir(self):
         # First call also creates the directory for us
         assert filesystem.get_unique_dir("/foo/bar", n=0, create_dir=True) == "/foo/bar"
@@ -1149,8 +1194,14 @@ class TestUnwantedExtensions:
 
 class TestDirectoryWriting:
     # very basic test of directory_is_writable()
+    # let's test on the tempdir provided by the OS:
     def test_directory_is_writable(self):
-        # let's test on the tempdir provided by the OS:
-        # on Windows, only basic writing testing will be done, and should succeed
-        # on non-Windows, assuming tempdir is not on FAT, full test should happen, and succeed
+        # verify directory is writable at all
         assert filesystem.directory_is_writable(tempfile.gettempdir())
+
+
+class FilesystemCapabilities:
+    def test_filesystem_capabilities(self):
+        # test the filesystem is capable of long and unicode filenames
+        # any modern filesystem (ext3, ext4, ntfs, modern FAT) should succeed
+        assert filesystem.check_filesystem_capabilities(tempfile.gettempdir())
