@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -55,7 +55,7 @@ class TestNewsUnpackFunctions:
 
     def test_sevenzip(self):
         testzip = newsunpack.SevenZip("tests/data/test_7zip/testfile.7z")
-        assert testzip.namelist() == ["testfile.bin"]
+        assert testzip.namelist() == ["My_Test_Download.bin"]
         # Basic check that we can get data from the 7zip
         assert len(testzip.open(testzip.namelist()[0]).read()) == 102400
 
